leaftools
=========

.. automodule:: abjad.tools.leaftools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.leaftools.Leaf.Leaf.Leaf

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.leaftools.make_leaves.make_leaves
      ~abjad.tools.leaftools.make_leaves_from_talea.make_leaves_from_talea
      ~abjad.tools.leaftools.make_tied_leaf.make_tied_leaf
